==> xfprint-4.1.90.tar.gz: xfprint-4.1.90/printing-systems/cups/cups.c <==
/*
 * Copyright (c) 2004 Jean-Franois Wauthy (pollux@xfce.org)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtk/gtkversion.h>
#if GTK_CHECK_VERSION(2, 4, 0)
#undef GTK_DISABLE_DEPRECATED
#endif

#include <gmodule.h>
#include <cups/ipp.h>
#include <cups/ppd.h>
#include <cups/cups.h>
#include <cups/language.h>
#include <libxfcegui4/libxfcegui4.h>
#include <libxfce4util/libxfce4util.h>
#include <printing-system.h>

static GList *printers = NULL;

/***************/
/* Main window */
/***************/
static GList *get_printers_list ()
{
  GList *list = NULL;
  int  i;
  cups_dest_t *dests;
  int  num_dests;

  num_dests = cupsGetDests (&dests); // Printer names and options

  if (num_dests > 0) {
    for (i = 0; i < num_dests; i ++){
      Printer *printer;
      http_t *HTTP;
      ipp_t *request = ippNew();
      cups_lang_t *lang = cupsLangDefault();
      ipp_attribute_t *attr;
      char buf[1024];

      printer = g_new0 (Printer, 1);
      printer->name = g_strdup (dests[i].name);
      list = g_list_append (list, printer);

      request->request.op.request_id = 1;
      ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_CHARSET, "attributes-charset", NULL, cupsLangEncoding(lang));
      ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE, "attributes-natural-language", NULL, lang->language);

      sprintf (buf,"ipp://localhost:631/printers/%s", dests[i].name);
      ippAddString (request, IPP_TAG_OPERATION,IPP_TAG_URI, "printer-uri", NULL, buf);
      request->request.op.operation_id = IPP_GET_PRINTER_ATTRIBUTES;

      HTTP = httpConnect ("localhost", 631);
      if (!HTTP) {
	ippDelete (request);
	continue;
      }

      request = cupsDoRequest (HTTP, request, "/printers/");
      httpClose (HTTP);

      if (!request)
	continue;
      if (request->state == IPP_ERROR || request->state == IPP_IDLE) {
	ippDelete (request);
	continue;
      }

      attr = ippFindAttribute(request,"printer-info",IPP_TAG_TEXT);
      if (!attr || strlen (attr->values[0].string.text) == 0) {
	attr = ippFindAttribute (request, "printer-make-and-model", IPP_TAG_TEXT);
	if (attr)
	  printer->alias = g_strdup (attr->values[0].string.text);
	else
	  printer->alias = g_strdup ("");
      } else
	printer->alias = g_strdup (attr->values[0].string.text);

      attr = ippFindAttribute(request,"printer-type",IPP_TAG_ENUM);
      if (attr && (attr->values[0].integer & CUPS_PRINTER_CLASS))
	printer->type = PRINTER_TYPE_CLASS;
      else 
	printer->type = PRINTER_TYPE_PRINTER;


      ippDelete (request);
    }
  }
  
  cupsFreeDests(num_dests, dests);

  return list;
}

/* Returns the printer list  */
/* returned pointer must be freed */
G_MODULE_EXPORT
GList* printing_system_get_printers_list_impl ()
{
  return get_printers_list ();
}

/* Customize main window */
G_MODULE_EXPORT
void printing_system_main_window_customize_impl (ManagerDlg *dlg)
{
  gtk_widget_set_sensitive (dlg->menuitem_setdefault, FALSE);
  gtk_widget_set_sensitive (dlg->menuitem_properties, FALSE);
}

G_MODULE_EXPORT
gboolean printing_system_set_default_printer_impl (const gchar *printer)
{
  return TRUE;
}

G_MODULE_EXPORT
Printer *printing_system_get_default_printer_impl (GList *printers)
{
  Printer *printer;

  printer = printer_lookup_byname (printers, cupsGetDefault ());

  return printer;
}

/****************/
/* Queue dialog */
/****************/

/* Refresh the job list */
/* returned pointer must be freed */
G_MODULE_EXPORT
GList *printing_system_get_jobs_list_impl (const gchar *printer)
{
  int        i;
  int        num_jobs;
  cups_job_t *jobs;
  GList *list = NULL;

  /* Obtain job list from cups server */
  num_jobs = cupsGetJobs(&jobs, printer, 0, 0);

  for (i = 0; i < num_jobs; i ++){
    Job *job;
    gchar string_creation_time[10] = "";
    gchar string_processing_time[10] = "";
    struct tm *local_time;

    job = g_new0 (Job, 1);

    job->name = g_strdup (jobs[i].title);
    job->id = jobs[i].id;
    job->user = g_strdup (jobs[i].user);
    job->state = g_strdup (jobs[i].state != IPP_JOB_PENDING ? _("printing") : _("pending"));
    job->size = g_strdup_printf ("%dKb", jobs[i].size);
    job->priority = g_strdup_printf ("%d", jobs[i].priority);
    local_time = localtime (&(jobs[i].creation_time));
    strftime (string_creation_time, sizeof(string_creation_time),
	      "%H:%M:%S", local_time);
    job->creation_time = g_strdup(string_creation_time);
    if(jobs[i].state == IPP_JOB_PROCESSING){
      local_time = localtime (&(jobs[i].processing_time));
      strftime (string_processing_time, sizeof(string_processing_time),
		"%H:%M:%S", local_time);
      job->processing_time = g_strdup (string_processing_time);

      list = g_list_append (list, job);
    }
  }

  cupsFreeJobs (num_jobs, jobs);

  return list;
}

/* Remove job from printer_name queue */
G_MODULE_EXPORT
gboolean printing_system_remove_job_impl (const gchar *printer, gint id)
{
  if (cupsCancelJob (printer, id) == 0){
    xfce_err (ippErrorString (cupsLastError ()));
    return FALSE;
  }

  return TRUE;
}

/* Customize the queue dialog */
G_MODULE_EXPORT
void printing_system_queue_dialog_customize_impl (QueueDlg *dialog)
{
}

/*********************/
/* Properties dialog */
/*********************/
/* Show the properties dialog */
G_MODULE_EXPORT
void printing_system_properties_dialog_run_impl (const gchar *printer)
{
}

/****************/
/* Print dialog */
/****************/
static gboolean destroy_print_dialog_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
  g_list_foreach (printers, (GFunc)printer_free, NULL);
  g_list_free (printers);

  return FALSE;
}

/* Customize the print dialog */
G_MODULE_EXPORT
void printing_system_print_dialog_customize_impl (PrintDlg *dialog)
{
  GList *printer_el;
  GList *list = NULL;
  Printer *printer;
  GtkWidget *hbox;
  GtkWidget *label;
  
  printers = get_printers_list ();

  g_signal_connect (G_OBJECT(dialog->dialog), "destroy_event",
		    G_CALLBACK(destroy_print_dialog_cb), printers);

  printer_el = g_list_first (printers);
  while (printer_el) {
    printer = printer_el->data;

    list = g_list_append (list, printer->alias);

    printer_el = g_list_next (printer_el);
  }

  hbox = gtk_hbox_new(FALSE, 5);

  label = gtk_label_new (_("Print to :"));
  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
  dialog->customization = (gpointer) gtk_combo_new ();
  gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (dialog->customization), TRUE, TRUE, 0);

  gtk_combo_set_popdown_strings (GTK_COMBO (dialog->customization), list);
  gtk_combo_set_value_in_list (GTK_COMBO (dialog->customization), TRUE, FALSE);

  /* select default printer */
  printer = printer_lookup_byname (printers, cupsGetDefault ());
  if (printer)
    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (dialog->customization)->entry), printer->alias);

  gtk_widget_show_all (hbox);
  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), hbox,
		      TRUE, TRUE, 0);

  gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), hbox, 0);

  g_list_free (list);
}

/************/
/* Printing */
/************/
G_MODULE_EXPORT
gboolean printing_system_print_file_impl (PrintDlg *dialog, const gchar *file)
{
  gchar *base_name = NULL;
  Printer *printer;
  gboolean ret = FALSE;

  base_name = g_path_get_basename (dialog->original_name);

  printer = printer_lookup_byalias (printers, gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (dialog->customization)->entry)));

  if (cupsPrintFile (printer->name, file, base_name, 0, NULL)){
    ret = TRUE;
  }else {
    xfce_err (ippErrorString (cupsLastError ()));
  }

  g_free (base_name);

  return ret;
}

/****************/
/* About dialog */
/****************/
G_MODULE_EXPORT
void printing_system_about_dialog_run_impl (GtkWidget *widget, gpointer data)
{
  XfceAboutInfo *info;
  GtkWidget *dialog;
  GdkPixbuf *icon = NULL;
  ManagerDlg *dlg;

  dlg = (ManagerDlg *) data;

  info = xfce_about_info_new ("xfprint-cups-plugin", VERSION,
			      _("CUPS plugin for Xfprint"),
			      XFCE_COPYRIGHT_TEXT("2004", "Xfce4 Team"),
			      XFCE_LICENSE_BSD);
  xfce_about_info_set_homepage (info, "http://www.xfce.org/");

  /* Credits */
  xfce_about_info_add_credit (info,
			      "Jean-Francois Wauthy",
			      "pollux@xfce.org",
			      _("Developer"));
  xfce_about_info_add_credit (info,
			      "Francois Le Clainche",
			      "fleclainche@wanadoo.fr",
			      _("Icon designer"));

  //  icon = xfce_themed_icon_load ("xfprint-cups-plugin" , 48);

  dialog = xfce_about_dialog_new (GTK_WINDOW (dlg->window), info, icon);

  gtk_window_set_default_size (GTK_WINDOW (dialog),500,400);
  xfce_about_info_free (info);

  gtk_dialog_run (GTK_DIALOG (dialog));
  
  gtk_widget_destroy (dialog);
}

/**********/
/* Others */
/**********/

/* Module informations initialization function */
G_MODULE_EXPORT
void printing_system_info_init_impl (PrintingSystemInfo *psinfo)
{
  psinfo->name = g_strdup ("CUPS");
  psinfo->description = g_strdup ("CUPS printing system support for Xfprint");
  psinfo->version = g_strdup (VERSION);
  psinfo->author = g_strdup ("Jean-Francois Wauthy");
  psinfo->homepage = g_strdup ("http://www.xfce.org");
}

==> xfprint-4.1.91.tar.gz: xfprint-4.1.91/printing-systems/cups/cups.c <==
/*
 * Copyright (c) 2004 Jean-Franois Wauthy (pollux@xfce.org)
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

#include <gtk/gtkversion.h>
#if GTK_CHECK_VERSION(2, 4, 0)
#undef GTK_DISABLE_DEPRECATED
#endif

#include <gmodule.h>
#include <cups/ipp.h>
#include <cups/ppd.h>
#include <cups/cups.h>
#include <cups/language.h>
#include <libxfcegui4/libxfcegui4.h>
#include <libxfce4util/libxfce4util.h>
#include <printing-system.h>

static GList *printers = NULL;

/***************/
/* Main window */
/***************/
static GList *get_printers_list ()
{
  GList *list = NULL;
  int  i;
  cups_dest_t *dests;
  int  num_dests;

  num_dests = cupsGetDests (&dests); // Printer names and options

  if (num_dests > 0) {
    for (i = 0; i < num_dests; i ++){
      Printer *printer;
      http_t *HTTP;
      ipp_t *request = ippNew();
      cups_lang_t *lang = cupsLangDefault();
      ipp_attribute_t *attr;
      char buf[1024];

      printer = g_new0 (Printer, 1);
      printer->name = g_strdup (dests[i].name);
      list = g_list_append (list, printer);

      request->request.op.request_id = 1;
      ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_CHARSET, "attributes-charset", NULL, cupsLangEncoding(lang));
      ippAddString (request, IPP_TAG_OPERATION, IPP_TAG_LANGUAGE, "attributes-natural-language", NULL, lang->language);

      sprintf (buf,"ipp://localhost:631/printers/%s", dests[i].name);
      ippAddString (request, IPP_TAG_OPERATION,IPP_TAG_URI, "printer-uri", NULL, buf);
      request->request.op.operation_id = IPP_GET_PRINTER_ATTRIBUTES;

      HTTP = httpConnect ("localhost", 631);
      if (!HTTP) {
	ippDelete (request);
	continue;
      }

      request = cupsDoRequest (HTTP, request, "/printers/");
      httpClose (HTTP);

      if (!request)
	continue;
      if (request->state == IPP_ERROR || request->state == IPP_IDLE) {
	ippDelete (request);
	continue;
      }

      attr = ippFindAttribute(request,"printer-info",IPP_TAG_TEXT);
      if (!attr || strlen (attr->values[0].string.text) == 0) {
	attr = ippFindAttribute (request, "printer-make-and-model", IPP_TAG_TEXT);
	if (attr)
	  printer->alias = g_strdup (attr->values[0].string.text);
	else
	  printer->alias = g_strdup ("");
      } else
	printer->alias = g_strdup (attr->values[0].string.text);

      attr = ippFindAttribute(request,"printer-type",IPP_TAG_ENUM);
      if (attr && (attr->values[0].integer & CUPS_PRINTER_CLASS))
	printer->type = PRINTER_TYPE_CLASS;
      else 
	printer->type = PRINTER_TYPE_PRINTER;


      ippDelete (request);
    }
  }
  
  cupsFreeDests(num_dests, dests);

  return list;
}

/* Returns the printer list  */
/* returned pointer must be freed */
G_MODULE_EXPORT
GList* printing_system_get_printers_list_impl ()
{
  return get_printers_list ();
}

/* Customize main window */
G_MODULE_EXPORT
void printing_system_main_window_customize_impl (ManagerDlg *dlg)
{
  gtk_widget_set_sensitive (dlg->menuitem_setdefault, FALSE);
  gtk_widget_set_sensitive (dlg->menuitem_properties, FALSE);
}

G_MODULE_EXPORT
gboolean printing_system_set_default_printer_impl (const gchar *printer)
{
  return TRUE;
}

G_MODULE_EXPORT
Printer *printing_system_get_default_printer_impl (GList *printers)
{
  Printer *printer;

  printer = printer_lookup_byname (printers, cupsGetDefault ());

  return printer;
}

/****************/
/* Queue dialog */
/****************/

/* Refresh the job list */
/* returned pointer must be freed */
G_MODULE_EXPORT
GList *printing_system_get_jobs_list_impl (const gchar *printer)
{
  int        i;
  int        num_jobs;
  cups_job_t *jobs;
  GList *list = NULL;

  /* Obtain job list from cups server */
  num_jobs = cupsGetJobs(&jobs, printer, 0, 0);

  for (i = 0; i < num_jobs; i ++){
    Job *job;
    gchar string_creation_time[10] = "";
    gchar string_processing_time[10] = "";
    struct tm *local_time;

    job = g_new0 (Job, 1);

    job->name = g_strdup (jobs[i].title);
    job->id = jobs[i].id;
    job->user = g_strdup (jobs[i].user);
    job->state = g_strdup (jobs[i].state != IPP_JOB_PENDING ? _("printing") : _("pending"));
    job->size = g_strdup_printf ("%dKb", jobs[i].size);
    job->priority = g_strdup_printf ("%d", jobs[i].priority);
    local_time = localtime (&(jobs[i].creation_time));
    strftime (string_creation_time, sizeof(string_creation_time),
	      "%H:%M:%S", local_time);
    job->creation_time = g_strdup(string_creation_time);
    if(jobs[i].state == IPP_JOB_PROCESSING){
      local_time = localtime (&(jobs[i].processing_time));
      strftime (string_processing_time, sizeof(string_processing_time),
		"%H:%M:%S", local_time);
      job->processing_time = g_strdup (string_processing_time);

      list = g_list_append (list, job);
    }
  }

  cupsFreeJobs (num_jobs, jobs);

  return list;
}

/* Remove job from printer_name queue */
G_MODULE_EXPORT
gboolean printing_system_remove_job_impl (const gchar *printer, gint id)
{
  if (cupsCancelJob (printer, id) == 0){
    xfce_err (ippErrorString (cupsLastError ()));
    return FALSE;
  }

  return TRUE;
}

/* Customize the queue dialog */
G_MODULE_EXPORT
void printing_system_queue_dialog_customize_impl (QueueDlg *dialog)
{
}

/*********************/
/* Properties dialog */
/*********************/
/* Show the properties dialog */
G_MODULE_EXPORT
void printing_system_properties_dialog_run_impl (const gchar *printer)
{
}

/****************/
/* Print dialog */
/****************/
static gboolean destroy_print_dialog_cb (GtkWidget *widget, GdkEvent *event, gpointer user_data)
{
  g_list_foreach (printers, (GFunc)printer_free, NULL);
  g_list_free (printers);

  return FALSE;
}

/* Customize the print dialog */
G_MODULE_EXPORT
void printing_system_print_dialog_customize_impl (PrintDlg *dialog)
{
  GList *printer_el;
  GList *list = NULL;
  Printer *printer;
  GtkWidget *hbox;
  GtkWidget *label;
  
  printers = get_printers_list ();

  g_signal_connect (G_OBJECT(dialog->dialog), "destroy_event",
		    G_CALLBACK(destroy_print_dialog_cb), printers);

  printer_el = g_list_first (printers);
  while (printer_el) {
    printer = printer_el->data;

    list = g_list_append (list, printer->alias);

    printer_el = g_list_next (printer_el);
  }

  hbox = gtk_hbox_new(FALSE, 5);

  label = gtk_label_new (_("Print to :"));
  gtk_box_pack_start (GTK_BOX (hbox), label, FALSE, TRUE, 0);
  dialog->customization = (gpointer) gtk_combo_new ();
  gtk_box_pack_start (GTK_BOX (hbox), GTK_WIDGET (dialog->customization), TRUE, TRUE, 0);

  gtk_combo_set_popdown_strings (GTK_COMBO (dialog->customization), list);
  gtk_combo_set_value_in_list (GTK_COMBO (dialog->customization), TRUE, FALSE);

  /* select default printer */
  printer = printer_lookup_byname (printers, cupsGetDefault ());
  if (printer)
    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (dialog->customization)->entry), printer->alias);

  if (g_list_length (list) == 0) {
    gtk_widget_set_sensitive (GTK_WIDGET (dialog->customization), FALSE);
    gtk_entry_set_text (GTK_ENTRY (GTK_COMBO (dialog->customization)->entry), _("No printer in the list"));
  }

  gtk_widget_show_all (hbox);
  gtk_box_pack_start (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), hbox,
		      TRUE, TRUE, 0);

  gtk_box_reorder_child (GTK_BOX (GTK_DIALOG (dialog->dialog)->vbox), hbox, 0);

  g_list_free (list);
}

/************/
/* Printing */
/************/
G_MODULE_EXPORT
gboolean printing_system_print_file_impl (PrintDlg *dialog, const gchar *file)
{
  gchar *base_name = NULL;
  Printer *printer;
  gboolean ret = FALSE;

  base_name = g_path_get_basename (dialog->original_name);

  printer = printer_lookup_byalias (printers, gtk_entry_get_text (GTK_ENTRY (GTK_COMBO (dialog->customization)->entry)));

  if (cupsPrintFile (printer->name, file, base_name, 0, NULL)){
    ret = TRUE;
  }else {
    xfce_err (ippErrorString (cupsLastError ()));
  }

  g_free (base_name);

  return ret;
}

/****************/
/* About dialog */
/****************/
G_MODULE_EXPORT
void printing_system_about_dialog_run_impl (GtkWidget *widget, gpointer data)
{
  XfceAboutInfo *info;
  GtkWidget *dialog;
  GdkPixbuf *icon = NULL;
  ManagerDlg *dlg;

  dlg = (ManagerDlg *) data;

  info = xfce_about_info_new ("xfprint-cups-plugin", VERSION,
			      _("CUPS plugin for Xfprint"),
			      XFCE_COPYRIGHT_TEXT("2004", "Xfce4 Team"),
			      XFCE_LICENSE_BSD);
  xfce_about_info_set_homepage (info, "http://www.xfce.org/");

  /* Credits */
  xfce_about_info_add_credit (info,
			      "Jean-Francois Wauthy",
			      "pollux@xfce.org",
			      _("Developer"));
  xfce_about_info_add_credit (info,
			      "Francois Le Clainche",
			      "fleclainche@wanadoo.fr",
			      _("Icon designer"));

  //  icon = xfce_themed_icon_load ("xfprint-cups-plugin" , 48);

  dialog = xfce_about_dialog_new (GTK_WINDOW (dlg->window), info, icon);

  gtk_window_set_default_size (GTK_WINDOW (dialog),500,400);
  xfce_about_info_free (info);

  gtk_dialog_run (GTK_DIALOG (dialog));
  
  gtk_widget_destroy (dialog);
}

/**********/
/* Others */
/**********/

/* Module informations initialization function */
G_MODULE_EXPORT
void printing_system_info_init_impl (PrintingSystemInfo *psinfo)
{
  psinfo->name = g_strdup ("CUPS");
  psinfo->description = g_strdup ("CUPS printing system support for Xfprint");
  psinfo->version = g_strdup (VERSION);
  psinfo->author = g_strdup ("Jean-Francois Wauthy");
  psinfo->homepage = g_strdup ("http://www.xfce.org");
}
